module ("basic_stats", package.seeall)

-- Load other source files
require ("basic_stats.output.csv")
require ("basic_stats.output.text")
require ("basic_stats.analyze")
require ("basic_stats.help")

--- Entry point of the module basic_stats
--@param args A table of parameters
--@param aproject An existing project
function basic_stats:basic_stats_launch (args, aproject)
   local help = basic_stats:init_help()
   -- Print version if -v or --version are passed in parameters
   if args.v == true or args.version == true then
      help:print_version (false)
   end

   -- Print help if -h or --help are passed in parameters
   if args.h == true or args.help == true then
      help:print_help (false)
   end

   -- If help or version have been displayed, exit
   if args.h == true or args.help == true
   or args.v == true or args.version == true then
      os.exit (0)
   end

   -- Load the binary and analyze it ------------------------------------------
	-- Check ig a binary has been passed
	if args.bin == nil then
	   Message:error ("No binary specified. use bin=<binary> to specify the binary to analyze")
	   os.exit (1)
	end
	
	-- Load it
	local binary = aproject:load (args.bin, aproject:get_uarch())
	if binary == nil then
	   Message:error ("The input binary can not be opened")
	   os.exit (2)
	end
	
	-- Analyze it (code is in analyze.lua)
	local results = basic_stats:analyze (binary)
	
	-- Print results of the analysis -------------------------------------------
	-- According to the format, call the corresponding function
	-- No value or "text" => print in text format
	if args.format == "text" 
	or args.format == nil then
	   basic_stats:display_text (results)
	
	-- "csv" format
	elseif args.format == "csv" then
	   basic_stats:display_csv (results)
	
	-- "table" format
	elseif args.format == "table" then
   	results:tostring ()
	
	-- unsupported format
	else
   	Message:error ("Unsupported format ["..args.format.."]")
   	os.exit (3)
	end
end

